@@ -3,6 +3,7 @@ import datetime
 import inspect
 import itertools
 import pickle
+from functools import wraps
 from pathlib import Path
 from typing import Callable
 
@@ -15,6 +16,7 @@ class IOHandler:
     """ Handle all read and write operations. """
 
     def __init__(self, base_read_path: Path = None, base_write_path: Path = None):
+        super().__init__()
         self.base_read_path = base_read_path
         self.base_write_path = base_write_path
 
@@ -22,6 +24,7 @@ class IOHandler:
     def add_base_read_path(func: Callable) -> Callable:
         """ Decorator to add the base_read_path to the filepath if it is not None """
 
+        @wraps(func)
         def wrapper(self, filepath: Path, **kwargs):
             if self.base_read_path:
                 filepath = self.base_read_path / filepath
@@ -33,6 +36,7 @@ class IOHandler:
     def add_base_write_path(func: Callable) -> Callable:
         """ Decorator to add the base_write_path to the filepath if it is not None """
 
+        @wraps(func)
         def wrapper(self, filepath: Path, **kwargs):
             if self.base_write_path:
                 filepath = self.base_write_path / filepath
